# melobot 文档

```{toctree}
:maxdepth: 2
:caption: 起步
:hidden:

intro/index
```


```{toctree}
:maxdepth: 2
:caption: 相关知识
:hidden:

ob_refer/index
```

```{toctree}
:maxdepth: 2
:caption: API 参考
:hidden:

api/index
ob_api/index
```

```{toctree}
:maxdepth: 2
:caption: 更多
:hidden:

update-log
melobot-prev
```

```{admonition} 重要提示
:class: caution
melobot 的文档仍在补充中，请及时关注文档更新。
```


```{include} ../../README.md
:start-after: <!-- start elevator-pitch -->
:end-before: <!-- end elevator-pitch -->
```
